{% if messages %}
	<div class="container">
	    <div class="row">
			{% for m in messages %}
                <div class="alert {{ message.tags }} alert-dismissible" role="alert">
                    <button type="button" class="close" data-dismiss="alert" aria-label="Close">
                        <span aria-hidden="true">&times;</span>
                    </button>
                    {{ m }}
                </div>
			{% endfor %}
	    </div>
	</div>
{% endif %}