# Generated by Django 2.0.10 on 2019-08-10 14:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangocopy', '0005_auto_20190807_2333'),
    ]

    operations = [
        migrations.AlterField(
            model_name='image',
            name='image',
            field=models.ImageField(upload_to='djangocopy/images/'),
        ),
        migrations.AlterField(
            model_name='template',
            name='template',
            field=models.FileField(upload_to='djangocopy/templates/'),
        ),
    ]
