{% extends "djangocopy/base.html" %}
{% load i18n %}

{% block breadcrumbs %}
<ul class="breadcrumbs">
  <li>{% trans "Error 500" %}</li>
</ul>
{% endblock breadcrumbs %}

{% block title %}{% trans "Server error" %}{% endblock title %}

{% block body-class %}error-500{% endblock body-class %}

{% block djangocopy-content %}
    <div class="container">
        <div class="col-sm-7">
            <h1>{% trans "Server error" %}</h1>
            <p>{% trans "There's been an error. It's been reported to the site administrators via e-mail and should be fixed shortly. Thanks for your patience." %}</p>
        </div>
    </div>
    {{ block.super }}
{% endblock djangocopy-content %}
