{% extends "djangocopy/base.html" %}
{% load i18n %}

{% block breadcrumbs %}
    <ul class="breadcrumbs">
      <li>{% trans "Error 404" %}</li>
    </ul>
{% endblock breadcrumbs %}

{% block title %}{% trans "Page not found" %}{% endblock title %}

{% block body-class %}error-404{% endblock body-class %}

{% block djangocopy-content %}
    <div class="container">
        <div class="col-sm-7">
            <h1>{% trans "Page not found" %}</h1>
            <p>{% trans "Sorry, but the requested page could not be found." %}</p>
        </div>
    </div>
    {{ block.super }}
{% endblock djangocopy-content %}
