{% extends "djangocopy/base.html" %}

{% block title %}Signout{% endblock %}

{% block djangocopy-content %}
    <div class="container">
      <div class="col-md-6 col-md-offset-3">
		<h1>Sign Out</h1>
		<p>You have been logged out. <a href="{% url 'login'%}">Click here to login again.</a>
      </div>
    </div>
{% endblock %}
