{% extends "djangocopy/base.html" %}

{% block title %}Password Reset Done{% endblock %}

{% block djangocopy-content %}
    <div class="container">
      <div class="col-md-6 col-md-offset-3">
		<h1>Password Reset</h1>
        <p>We've emailed you instructions for setting your password. If they haven't arrived in a few minutes, check your spam folder.</p>
		<p><a href="{% url 'login'%}">Click here to login again.</a>
      </div>
    </div>
{% endblock %}
