Please follow the link below to reset the password for {{ email }}:

{{ protocol}}://{{ domain }}{% url 'password_reset_confirm' uidb64=uid token=token %}


If you didn't request this password change, please inform the Forum administrator at admin@altimapa.com
